#!/bin/bash

main() {
   #check which user is executing the script
   if [ "$(whoami)" != "root" ]; then
        echo "Script must be run as user: root"
        exit 255
   fi

   replaceProfiles
   enableNewProfile
   disableIRQBalancer
   installManualIRQBalancer
   checkEnvironment
}

replaceProfiles() {
  #remove old Profiles
  rm -rf /usr/lib/tuned/juststore-editing/*
  rm -rf /usr/lib/tuned/juststore-playout/*
  rm -rf /usr/lib/tuned/juststore-ingest/*

  #copy new profiles
  cp -fv profiles/juststore-editing/* /usr/lib/tuned/juststore-editing
  cp -fv profiles/juststore-playout/* /usr/lib/tuned/juststore-playout
  cp -fv profiles/juststore-ingest/* /usr/lib/tuned/juststore-ingest
}

enableNewProfile() {
  tuned-adm profile juststore-editing
}

disableIRQBalancer() {
  systemctl stop irqbalance
  systemctl disable irqbalance

  echo "# Sys
tuna --irqs=timer,rtc0,acpi,i801\*,xhc\*,pcie\*,dmar\*,0000\* --cpus=0,1,2 --spread
# Raid Controller
tuna --irqs=aacraid --cpus=3,4,5 --spread
# 1G NW Card
tuna --irqs=p3p\* --cpus=6,7,8 --spread
tuna --irqs=p2p\* --cpus=6,7,8 --spread
# 10G NW Card
tuna --irqs=i40\* --cpus=9,10,11 --spread">/home/toaadmin/tuna.sh

  grep -q -F "@reboot /home/toaadmin/tuna.sh" /var/spool/cron/root || echo "@reboot /home/toaadmin/tuna.sh" >> /var/spool/cron/root
}

installManualIRQBalancer() {
  yum install rpms/* -y

  tuna -Q >> /home/toaadmin/juststore-interrupts.log
}

checkEnvironment(){
  dirtyRatio=$(sysctl vm.dirty_ratio|cut -d '=' -f2| xargs)
  bckRatio=$(sysctl vm.dirty_background_ratio|cut -d '=' -f2| xargs)
  centisecsExpire=$(sysctl vm.dirty_expire_centisecs|cut -d '=' -f2| xargs)
  centisecsWriteBack=$(sysctl vm.dirty_writeback_centisecs|cut -d '=' -f2| xargs)

  if [ $dirtyRatio -eq 30 ] ||  [ $bckRatio -eq 10 ] || ([ $centisecsExpire -eq 3000 ] && [ $centisecsWriteBack -eq 1000 ]); then
    echo "Patch successfully installed. Please restart the system when possible."
    echo "Please check the following value in the file: /sys/block/sd[a,b,c,d,e]/queue/iosched/quantum"
  fi
}

main
